Module updates

Module updates 

Tools for defining updates to be performed on an item in the database.

Structs

Updates
Builder type to build a list of updates to perform.

Enums

Action
Enum specifying the variants of actions to be performed when updating the item. The type contains factory methods to facilitate the construction of variants. Check deta docs for more information.