Action

Enum Action 

pub enum Action {
    Set(Value),
    Increment(f64),
    Append(Vec<Value>),
    Prepend(Vec<Value>),
    Delete,
}
Enum specifying the variants of actions to be performed when updating the item. The type contains factory methods to facilitate the construction of variants. Check deta docs for more information.

Variants



Set(Value)

The attribute to be updated or created.



Increment(f64)

The attribute to be incremented. Increment value can be negative.



Append(Vec<Value>)

The attribute to append a values to.



Prepend(Vec<Value>)

The attribute to prepend a values to.



Delete

The attribute to be deleted.

Implementations

Source

impl Action

Factory methods.

pub fn set<T>(value: T) -> Result<Self>
where T: Serialize,

pub fn increment<T>(value: T) -> Self
where T: Into<f64>,

pub fn append<T>(value: T) -> Result<Self>
where T: Serialize,

pub fn append_many<T>(value: &[T]) -> Result<Self>
where T: Serialize,

pub fn prepend<T>(value: T) -> Result<Self>
where T: Serialize,

pub fn prepend_many<T>(value: &[T]) -> Result<Self>
where T: Serialize,

pub fn delete() -> Self