Module updates
deta_
rust
0.3.1
Module updates
Module Items
Structs
Enums
In deta_
rust::
database
deta_rust
::
database
Module
updates
Tools for defining updates to be performed on an item in the database.
Structs

Updates
Builder type to build a list of updates to perform.
Enums

Action
Enum specifying the variants of actions to be performed when updating the item. The type contains factory methods to facilitate the construction of variants. Check
deta docs
for more information.